package com.sun.org.apache.xml.internal.security.exceptions;

import java.text.MessageFormat;
import com.sun.org.apache.xml.internal.security.utils.I18n;

public class XMLSecurityException extends Exception
{
    private static final long serialVersionUID = 1L;
    protected String msgID;
    
    public XMLSecurityException() {
        super("Missing message string");
        this.msgID = null;
    }
    
    public XMLSecurityException(String s) {
        super(I18n.getExceptionMessage(s));
        this.msgID = s;
    }
    
    public XMLSecurityException(String s, Object[] arguments) {
        super(MessageFormat.format(I18n.getExceptionMessage(s), arguments));
        this.msgID = s;
    }
    
    public XMLSecurityException(Exception cause) {
        super(cause.getMessage(), cause);
    }
    
    public XMLSecurityException(Exception ex, String s) {
        super(I18n.getExceptionMessage(s, ex), ex);
        this.msgID = s;
    }
    
    @Deprecated
    public XMLSecurityException(String s, Exception ex) {
        this(ex, s);
    }
    
    public XMLSecurityException(Exception cause, String s, Object[] arguments) {
        super(MessageFormat.format(I18n.getExceptionMessage(s), arguments), cause);
        this.msgID = s;
    }
    
    @Deprecated
    public XMLSecurityException(String s, Object[] array, Exception ex) {
        this(ex, s, array);
    }
    
    public String getMsgID() {
        if (this.msgID == null) {
            return "Missing message ID";
        }
        return this.msgID;
    }
    
    @Override
    public String toString() {
        String name = this.getClass().getName();
        String localizedMessage = super.getLocalizedMessage();
        String str;
        if (localizedMessage != null) {
            str = name + ": " + localizedMessage;
        }
        else {
            str = name;
        }
        if (super.getCause() != null) {
            str = str + "\nOriginal Exception was " + super.getCause().toString();
            return str;
        }
        return str;
    }
    
    @Override
    public void printStackTrace() {
        synchronized (System.err) {
            super.printStackTrace(System.err);
        }
    }
    
    public Exception getOriginalException() {
        if ((this.getCause() instanceof Exception)) {
            return (Exception)this.getCause();
        }
        return null;
    }
}
